@@ -2,6 +2,10 @@ from iqrfpy.messages.requests.coordinator import *
 from iqrfpy.transports.itransport import ITransport
 from iqrfpy.messages.requests.coordinator.AuthorizeBond import AuthorizeBondParams
 
+trans = ITransport()
+
+trans.receive()
+
 data = [
     AuthorizeBondParams(reqAddr=1, mid=0),
     AuthorizeBondParams(reqAddr=2, mid=2164554855),
